function p_PlotScenarioResults_02092018(FractionalChange, RatioChange, AggLabel, BuildGroup, target_groups, y_axis)
% plot static ECOTRAN scenario results
% Jim Ruzicka
% takes:
%       FractionalChange
%       RatioChange
%       AggLabel
%       BuildGroup
%       target_groups
%       y_axis
% calls:
%       myboxplot_4.m         (modified version of boxplot utility from Jorn Diedrichson toolbox)
%       round2.m
% revision date: 2-9-2018



% *************************************************************************
% STEP 1: decide wheter to plot FractionalChange or RatioChange------------
% step 1a: set label parameters
font_angle          = 45;
% font_color          = [0, 0, 1]; 
font_color          = 'k';
font_size           = 10;
font_weight         = 'normal'; % font_weight  = 'bold';
font_name           = 'Helvetica'; % font_name    = 'Ariel';
line_width          = 0.1;
title_switch        = 'off'; % turn title on or off
H_alignment         = 'right';
axis_position       = [0.13 0.25 0.775 0.7]; % [left bottom width height]
% axis_position       = [0.13 0.35 0.775 0.6]; % [left bottom width height]
xlabel_offset       = 1.02;
y_tick_step         = 0.2; % 0.1
BoxColor            = 'k';
BoxFillColor        = 'r';
MedianColor         = 'k';

% step 1b: decide wheter to plot FractionalChange or RatioChange------------
plot_type           = 'FractionalChange'; % type of results to plot 'FractionalChange' or 'RatioChange'
plot_orientation    = 'horizontal';

% step 1c: set defualt parameters
if strcmp(plot_type, 'FractionalChange')
    
    ResultsToPlot   = FractionalChange;
    response_label  = 'Relative Change in Biomass & Landings';
    xmin_default    = 0.5;
    ymin_default    = -0.6; % default
    ymax_default    = 0.25; % default
    
elseif strcmp(plot_type, 'RatioChange')
    
    ResultsToPlot   = RatioChange;
    response_label  = 'Ratio of Production Change (modified : base)';
    
end





% *************************************************************************
% STEP 2: pick out target groups to plot & order to plot them--------------
% step 2a: filter results to target groups
[E2E_rows, num_trials] = size(FractionalChange);
if isempty(target_groups); target_groups = 1:E2E_rows; end

target_ResultsToPlot   = FractionalChange(target_groups, :);
target_BuildGroup      = BuildGroup(target_groups, :);
target_Labels          = AggLabel(target_groups);
[E2E_rows, num_trials] = size(target_ResultsToPlot); % get the new sizes for the target-plotting set

% step 2b: re-number target_BuildGroup 
% (this is for myboxplot which will resort groups according to increasing target_BuildGroup numbers)
for MonteCarlo_loop = 1:num_trials
    target_BuildGroup(:, MonteCarlo_loop) = (1:E2E_rows)';
end





% *************************************************************************
% STEP 2: set axis ranges--------------------------------------------------
xmin            = xmin_default;
xmax            = (E2E_rows+0.5);

if exist('y_axis')
    ymin = y_axis(1);
    ymax = y_axis(2);
else
    ymin = ymin_default; % default
    ymax = ymax_default; % default
end

y_tick_marks    = [round2(ymin, 1) : y_tick_step : round2(ymax, 1)];



% *************************************************************************
% STEP 3: plot scenario results--------------------------------------------
if num_trials == 1
    % plot single static scenario
    fig1 = figure;
    
    
    if strcmp(plot_orientation, 'horizontal')
        ax1   = axes('Position', axis_position); % default was Position = [0.13 0.11 0.775 0.815]
        bar(target_ResultsToPlot)
        hold on
        
        ylabel(response_label, 'fontweight', font_weight, 'fontname', font_name)
        set(gca, 'xtick', [], 'xticklabel', '')
        set(gca, 'ytick', y_tick_marks)
        set(gca, 'fontname', font_name, 'fontweight', font_weight, 'fontsize', font_size, 'linewidth', line_width)

        % title(['Distribution of n = ' num2str(num_trials) ' sampled food webs'])
        axis([xmin xmax ymin ymax])
        plot([xmin xmax], [0 0], 'k--', 'linewidth', line_width)
   
        % plot x-axis labels
        data_x  = 1:E2E_rows;
        for label_loop = 1:E2E_rows
            text(data_x(label_loop), (ymin * 1.05), target_Labels(label_loop), 'Rotation', -45, 'color', 'b')
        end
        
    elseif strcmp(plot_orientation, 'vertical')
        error('vertical orientation not supported')
        
%         % barh(flipud(target_ResultsToPlot))
%         bar(target_ResultsToPlot)
%     
%         set(gca, 'Ytick', (target_BuildGroup))
%         set(gca,'YTickLabel', num2str(flipud(target_BuildGroup)))
%         % set(gca,'YTickLabel', flipud(agg_labels))
%         % title('b')
%         % axis([-0.5 0.5 0.5 (length(target_ResultsToPlot)+0.5)])
%         xlabel('Relative Change in Productivity')
%     
%         axis([0 2 0.5 (length(target_ResultsToPlot)+0.5)])
%         xlabel(x_label)
        
    end
        

elseif num_trials > 1 
    % plot Monte Carlo distribution
    fig_1 = figure;
    
    if strcmp(plot_orientation, 'horizontal')
        ax1   = axes('Position', axis_position); % defualt was Position = [0.13 0.11 0.775 0.815]
        
        myboxplot_5(target_BuildGroup(:), target_ResultsToPlot(:), 'style_tukey3', ...
            'linecolor', BoxColor, 'fillcolor', BoxFillColor, 'mediancolor', MedianColor, ...
            'linewidth', line_width, 'whiskerwidth', line_width, 'medianwidth', line_width)
        
        hold on
        ylabel(response_label, 'fontname', font_name, 'fontweight', font_weight, 'fontsize', font_size)
        set(gca, 'xtick', [], 'xticklabel', '')
        set(gca, 'ytick', y_tick_marks)
%         set(gca, 'fontname', font_name, 'fontweight', font_weight, 'fontsize', font_size, 'linewidth', line_width)
        set(gca, 'fontname', font_name, 'fontweight', font_weight, 'fontsize', font_size)

        if strcmp(title_switch, 'on')
            title(['Distribution of n = ' num2str(num_trials) ' sampled food webs'])
        end
        axis([xmin xmax ymin ymax])
        plot([xmin xmax], [0 0], 'k:', 'linewidth', line_width)
   
        % plot x-axis labels
        data_x  = 1:E2E_rows;
        for label_loop = 1:E2E_rows
            text(data_x(label_loop), (ymin*xlabel_offset), target_Labels(label_loop), 'HorizontalAlignment', H_alignment, 'Rotation', font_angle, 'color', font_color, 'fontname', font_name, 'fontsize', font_size)
        end
    
    elseif strcmp(plot_orientation, 'vertical')
        error('vertical orientation not supported')
    end
    
end

% end m-file***************************************************************